# langley

A headquarters for your agents.

[![Build Status](https://github.com/1kbgz/langley/actions/workflows/build.yaml/badge.svg?branch=main&event=push)](https://github.com/1kbgz/langley/actions/workflows/build.yaml)
[![codecov](https://codecov.io/gh/1kbgz/langley/branch/main/graph/badge.svg)](https://codecov.io/gh/1kbgz/langley)
[![License](https://img.shields.io/github/license/1kbgz/langley)](https://github.com/1kbgz/langley)
[![PyPI](https://img.shields.io/pypi/v/langley.svg)](https://pypi.python.org/pypi/langley)

## Overview

> [!WARNING]
> This project is in early alpha. Expect breaking changes, rough edges, and incomplete features. Feedback and contributions are very welcome!

[![Sample screenshot](https://raw.githubusercontent.com/1kbgz/langley/refs/heads/main/docs/img/sample.png)](https://raw.githubusercontent.com/1kbgz/langley/refs/heads/main/docs/img/sample.png)

> [!NOTE]
> This library was generated using [copier](https://copier.readthedocs.io/en/stable/) from the [Base Python Project Template repository](https://github.com/python-project-templates/base).
